@@ -1,7 +1,7 @@
 package Net::Google::DataAPI::Role::Auth;
 use Any::Moose '::Role';
-use namespace::autoclean;
-
 requires 'sign_request';
+no Any::Moose '::Role';
+our $VERSION = '0.02';
 
 1;
